import 'fs';
import fs from 'fs-extra';
import walk from 'walk';
import log from '../utils/log';


export default {
    import : _import
};

function _import(opts = {}) {
    if(!opts.from || !opts.to){
        throw new Error('Invalid options, please fill FROM/TO paths');
    }

    // Default options to walk
    let _default = {
        from: opts.from,
        to: opts.to,
        onFile: function (root, stats, next) {
            // Copy only if is file
            if(stats.type === 'file'){
                log.info(`Copying file ${root}/${stats.name} to ${opts.to}/${stats.name}`);
                fs.copySync(`${root}/${stats.name}`, `${opts.to}/${stats.name}`);
            }
            next();
        },
        onError: function (root, error, next) {
            next();
        },
        onEnd: function () {
            opts.onEnd();
        }
    };

    // Walk on each file
    let walker = walk.walk(_default.from, {followLinks: false});

    walker.on('file', _default.onFile);
    walker.on('error', _default.onError);
    walker.on('end', _default.onEnd);
}
