import {expect, assert} from 'chai';
import mockfs from 'mock-fs';
import importer from '../../src/lib/importer';
import fs from 'fs';

describe('Importer', () => {
    describe('import()', () => {
        it('should throw an Error when no FROM/TO path is provided', () => {
            var opts = {};
            var fn = function(){
                importer.import(opts);
            };
            expect(fn).to.throw(Error);
        });
        it('should COPY nothing when origin path is empty', (done) => {
            mockfs({
                '/origin' : {},
                '/destination' : {}
            });
            var opts = {
                from : '/origin',
                to : '/destination',
                onEnd : () => {
                    // Destination path should be empty
                    let destPath = fs.readdirSync('/destination');
                    expect(destPath.length).to.be.equal(0);
                    mockfs.restore();
                    done();
                }
            };

            importer.import(opts);
        });
        it('should COPY single fileA.png from origin to destination', (done) => {
            mockfs({
                '/pathA' : {
                    'fileA.png' : 'Test'
                },
                '/pathB' : {}
            });
            var opts = {
                from : '/pathA',
                to : '/pathB',
                onEnd : function(){
                    //Read files from destination path B
                    var list = fs.readdirSync('/pathB');
                    // Expects to contains same fileA.png
                    expect(list).to.include('fileA.png');

                    mockfs.restore();
                    done();
                }
            };
            importer.import(opts);
        });
        it('should COPY only fileA.png NOT directories', (done) => {
            mockfs({
                '/origin' : {
                    'fileA.png' :'',
                    'dir1' : {
                    },
                    'dir2': {}
                },
                '/destination' : {}
            });
            var opts = {
                from : '/origin',
                to : '/destination',
                onEnd : () => {
                    //Expect to have one file (fileA)
                    let destPath = fs.readdirSync('/destination');
                    expect(destPath.length).to.be.equal(1);
                    expect(destPath[0]).to.be.equal('fileA.png');

                    mockfs.restore();
                    done();
                }
            };
            importer.import(opts);
        });
        it('should COPY all files from origin to destination', (done) => {
            mockfs({
                '/origin' : {
                    'fileA.png' : '',
                    'fileB.png' : '',
                    'fileC.png' : ''
                },
                '/destination' : {

                }
            });

            var opts = {
                from : '/origin',
                to : '/destination',
                onEnd : () => {
                    // Expect destination to have 3 files [fileA, fileB, fileC]
                    let destPath = fs.readdirSync('/destination');
                    expect(destPath.length).to.be.equal(3);
                    mockfs.restore();
                    done();
                }
            };

            importer.import(opts);

        });

    });
});
